"""Top-level package for air-markdown."""

__author__ = """Daniel Roy Greenfeld"""
__email__ = 'daniel@feldroy.com'

from .tags import Markdown as Markdown
from .tags import TailwindTypographyMarkdown as TailwindTypographyMarkdown